package com.knauf.ejb.kuchen;

import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.EntityContext;
import javax.ejb.EntityBean;

/**
 * Title:
 * Description:  Abstrakte Bean-Klasse fr ein Objekt "Kuchen".
 * Sie hat genau ein weiteres Feld: "Kuchen-Name".
 * Die ID wird vom Container erzeugt.
 *
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public abstract class KuchenSingleBean implements EntityBean
{
  private EntityContext entityContext = null;

  private static final Logger logger = Logger.getLogger ( KuchenSingleBean.class.getName() );

  public KuchenSingleBean()
  {
  }

  public void ejbActivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbActivate");
  }

  public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbLoad");
  }

  public void ejbPassivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbPassivate");
  }

  public void ejbRemove() throws javax.ejb.RemoveException, javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbRemove");
  }

  public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenSingleBean.logger.info("ejbStore");
  }

  public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    this.entityContext = null;
  }
  public void setEntityContext(EntityContext parm1) throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    this.entityContext = parm1;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////
  public abstract String getName();

  public abstract void setName (String str_Name);

  //////////////////////////////////////////////////////////////////////////////////
  //                          Weitere Methoden                                    //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird. Der Key wird (hoffentlich)
   * vom Container erzeugt.
   * @param str_Name Der Name des Kuchens.
   * @return Immer NULL.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreateByName (String str_Name) throws CreateException
  {
    KuchenSingleBean.logger.info("ejbCreateByName: " + str_Name);
    this.setName(str_Name);

    return null;
  }

  /**Erzeugen eines Kuchen-Objekts, Name ist noch nicht gegeben. Der Key wird (hoffentlich)
   * vom Container erzeugt.
   * @return Immer NULL.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreate () throws CreateException
  {
    KuchenSingleBean.logger.info("ejbCreate");
    return null;
  }

  /**Nach dem Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird: nichts besonderes zu tun.
   * @param str_Name Der Name des Kuchens.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByName (String str_Name) throws CreateException
  {
    KuchenSingleBean.logger.info("ejbPostCreateByName: " + str_Name);
  }

  /**Nach dem Erzeugen eines Kuchen-Objekts, Name ist noch nicht gegeben.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate () throws CreateException
  {
    KuchenSingleBean.logger.info("ejbPostCreate");
  }
}