package com.knauf.ejb.kuchenzutat;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.EntityContext;
import javax.ejb.EntityBean;

/**
 * Title:
 * Description:  Abstrakte Bean-Klasse fr ein Objekt "Kuchen".
 * Sie hat genau ein weiteres Feld: "Kuchen-Name".
 * Die ID wird vom Container erzeugt.
 *
 * Hier kommt noch die Zutatenliste hinzu.
 *
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public abstract class KuchenBean implements EntityBean
{
  private EntityContext entityContext = null;

  private static final Logger logger = Logger.getLogger ( KuchenBean.class.getName() );

  public KuchenBean()
  {
  }

  public void ejbActivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenBean.logger.info("ejbActivate");
  }

  public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenBean.logger.info("ejbLoad");
  }

  public void ejbPassivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenBean.logger.info("ejbPassivate");
  }

  public void ejbRemove() throws javax.ejb.RemoveException, javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenBean.logger.info("ejbRemove");
  }

  public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    KuchenBean.logger.info("ejbStore");
  }

  public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    this.entityContext = null;
  }
  public void setEntityContext(EntityContext parm1) throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    this.entityContext = parm1;
  }


  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////

  /**Abrufen der Kuchen-ID
   * @return Die Kuchen-ID
   */
  public abstract Integer getId();

  /**Setzen der Kuchen-Id.
   * @param int_Id Die neue ID.
   */
  public abstract void setId (Integer int_Id);


  /**Abrufen des Kuchen-Namens.
   * @return der Kuchen-Name.
   */
  public abstract String getName();

  /**Setzen des Kuchen-Namens.
   * @param str_Name der Name
   */
  public abstract void setName (String str_Name);

  /**Abrufen aller Zutaten dieses Kuchens.
   * @return Collection von Zutat-Objekten.
   */
  public abstract Collection getZutaten();

  /**Setzen der kompletten Zutaten-Liste des Kuchens.
   * Wird vom Container bernommen.
   * @param coll_Zutaten Liste der Zutaten.
   */
  public abstract void setZutaten (Collection coll_Zutaten);

  /**Hinzufgen einer Zutat zu den Zutaten dieses Kuchens (die einzige Business-Methode).
   * @param zutat Die zuzufgende Zutat.
   */
  public void addZutat (LocalZutat zutat)
  {
    Collection collZutaten = this.getZutaten();
    collZutaten.add( zutat);
    KuchenBean.logger.info("Anzahl Zutaten: " + collZutaten.size() );
  }

  /**Abrufen der Zutatenliste.
   * NUR hierber darf ein Client an die Zutaten kommen. "getZutaten" ist nur fr den Container ?
   * @return Eine Liste aller Zutaten.
   */
  public ArrayList getZutatenListe()
  {
    ArrayList list = new ArrayList();
    Iterator c = this.getZutaten().iterator();
    while (c.hasNext())
    {
      list.add((LocalZutat)c.next());
    }
    return list;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                          SELECT-Methoden                                     //
  //////////////////////////////////////////////////////////////////////////////////

  /**Ermitteln der maximalen Kuchen-ID in Datenbank
   * Der EJB-QL-Befehl wird per Deploytool festgelegt.
   * (select max (....)
   * @return Maximale ZutatID aus Datenbank.
   */
  public abstract Integer ejbSelectMaxId() throws javax.ejb.FinderException;

  /**Von auen verwendbare Methode aus dem Home-Interface: Ermitteln der nchsten verfgbaren
   * Kuchen-ID.
   * @return Die neue Kuchen-ID, 1 grer als die maximal vorhandene ID. Wenn es keine gibt,
   * wird "1" zurckgeliefert.
   */
  public Integer ejbHomeGetNextId()
  {
    Integer intMaxID = null;
    try
    {
      intMaxID = this.ejbSelectMaxId();
    }
    catch (javax.ejb.FinderException fex)
    {
      throw new javax.ejb.EJBException ("Konnte MaxID fr Kuchen nicht ermitteln", fex);
    }

    if (intMaxID == null)
      intMaxID = new Integer (0);
    //Um 1 erhhen:
    return new Integer (intMaxID.intValue() + 1);
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                          Weitere Methoden                                    //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird. Der Key wird automatisch erzeugt.
   * @param str_Name Der Name des Kuchens.
   * @return Die ID des Kuchens.
   * @exception CreateException Fehler beim Erzeugen.
   */
  //public Object ejbCreateByName (String str_Name) throws CreateException
  public Integer ejbCreateByName (String str_Name) throws CreateException
  {
    KuchenBean.logger.info("ejbCreateByName: " + str_Name);
    this.setName(str_Name);

    //Key erzeugen:
    this.setId ( this.ejbHomeGetNextId() );
    //return null;
    return this.getId();
  }

  /**Erzeugen eines Kuchen-Objekts, Name ist noch nicht gegeben. Der Key wird automatisch erzeugt.
   * @return Die ID des Kuchens.
   * @exception CreateException Fehler beim Erzeugen.
   */
  //public Object ejbCreate () throws CreateException
  public Integer ejbCreate () throws CreateException
  {
    KuchenBean.logger.info("ejbCreate");
    //Key erzeugen:
    this.setId ( this.ejbHomeGetNextId() );

    return this.getId();
  }

  /**Nach dem Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird: nichts besonderes zu tun.
   * @param str_Name Der Name des Kuchens.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByName (String str_Name) throws CreateException
  {
    KuchenBean.logger.info("ejbPostCreateByName: " + str_Name);
  }

  /**Nach dem Erzeugen eines Kuchen-Objekts, Name ist noch nicht gegeben.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate () throws CreateException
  {
    KuchenBean.logger.info("ejbPostCreate");
  }
}