package com.knauf.ejb.kuchenzutat;

import java.rmi.RemoteException;
import java.util.Collection;
import javax.ejb.CreateException;
import javax.ejb.EJBLocalHome;
import javax.ejb.FinderException;

/**
 * Title:
 * Description:  Local-Home-Interface des leckeren Kuchens.
 *               Deklariert die diversen Create-Methoden.
 *               Darf kein Remote-Home-Interface sein, da in beide Richtungen (von Kuchen zu Zutat und
 *               von Zutat zu Kuchen) referenziert werden kann.
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public interface LocalKuchenHome extends EJBLocalHome
{
  /**Erzeugen eines Kuchen-Objekts, wobei der Name angegeben wird. Der Key wird automatisch erzeugt.
   * @param str_Name Der Name des Kuchens.
   * @return Der erzeugte Kuchen.
   * @exception CreateException Fehler beim Erzeugen.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalKuchen createByName (String str_Name) throws CreateException, RemoteException;

  /**Erzeugen eines Kuchen-Objekts, Name ist noch nicht gegeben. Der Key wird automatisch erzeugt.
   * @return Der erzeugte Kuchen.
   * @exception CreateException Fehler beim Erzeugen.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalKuchen create () throws CreateException, RemoteException;

  /**Laden eines Kuchen-Objekts anhand des Primary Keys "Kuchen-ID"
   * @param int_PrimaryKey Der Key des Kuchens.
   * @return Den anhand des Keys gefundenen Kuchen.
   * @exception FinderException Fehler beim Finden.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalKuchen findByPrimaryKey(Integer int_PrimaryKey) throws FinderException, RemoteException;


  /**Laden aller Kuchen-Objekte.
   * @return Eine Collection aller Kuchen.
   * @exception FinderException Fehler beim Finden.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public Collection findAll() throws FinderException, RemoteException;

  /**Ermitteln der nchsten Zutat-ID.
   * D.h: Es wird Max(ID) + 1 zurckgeliefert.
   * @return Maximale Zutat-ID + 1
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public Integer getNextId() throws RemoteException;
}