package com.knauf.ejb.kuchenzutat;

import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.EntityContext;
import javax.ejb.EntityBean;

/**
 * Title:
 * Description:  Diese Bean bildet eine Zutat fr den Kuchen ab.
 *               Werte sind:
 *               a) ID (Versuch ohne Auto-Generierte Primary Keys !
 *               b) Name der Zutat
 *               c) Menge
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public abstract class ZutatBean implements EntityBean
{
  private EntityContext entityContext = null;

  private static final Logger logger = Logger.getLogger ( ZutatBean.class.getName() );

  public ZutatBean()
  {
  }

  public void ejbActivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("ejbActivate");
  }
  public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("ejbLoad");
  }
  public void ejbPassivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("ejbPassivate");
  }
  public void ejbRemove() throws javax.ejb.RemoveException, javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("ejbRemove");
  }
  public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("ejbStore");
  }
  public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("unsetEntityContext");
    this.entityContext = null;
  }
  public void setEntityContext(EntityContext parm1) throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatBean.logger.info("setEntityContext");
    this.entityContext = parm1;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////
  public abstract Integer getId();

  public abstract void setId (Integer int_Id);

  public abstract String getZutatName();

  public abstract void setZutatName (String str_Name);

  public abstract String getMenge();

  public abstract void setMenge (String str_Menge);

  /**Abrufen des Kuchens, zu dem die Zutat gehrt.
   * @return Der Kuchen der Zutat.
   */
  public abstract LocalKuchen getKuchen();

  /**Setzen des Kuchens, zu dem die Zutat gehrt.
   * @param kuchen Der Kuchen der Zutat.
   */
  public abstract void setKuchen(LocalKuchen kuchen);

  //////////////////////////////////////////////////////////////////////////////////
  //                          SELECT-Methoden                                     //
  //////////////////////////////////////////////////////////////////////////////////

  /**Ermitteln der maximalen Zutat-ID in Datenbank
   * Der EJB-QL-Befehl wird per Deploytool festgelegt.
   * (select max (....)
   * @return Maximale ZutatID aus Datenbank.
   */
  public abstract Integer ejbSelectMaxId() throws javax.ejb.FinderException;

  /**Von auen verwendbare Methode aus dem Home-Interface: Ermitteln der nchsten verfgbaren
   * Zutat-ID.
   * @return Die neue Zutat-ID, 1 grer als die maximal vorhandene ID. WEnn es keine gibt,
   * wird "1" zurckgeliefert.
   */
  public Integer ejbHomeGetNextId()
  {
    Integer intMaxID = null;
    try
    {
      intMaxID = this.ejbSelectMaxId();
    }
    catch (javax.ejb.FinderException fex)
    {
      throw new javax.ejb.EJBException ("Konnte MaxID fr Zutat nicht ermitteln", fex);
    }

    if (intMaxID == null)
      intMaxID = new Integer (0);
    //Um 1 erhhen:
    return new Integer (intMaxID.intValue() + 1);
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                          Weitere Methoden                                    //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Zutat-Objekts, wobei Name und Menge angegeben wird. Der Key wird in der MEthode
   * erzeugt.
   * @param str_Name Der Name der Zutat
   * @param str_Menge Die Menge der Zutat
   * @return Immer NULL.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Integer ejbCreateByNameMenge (String str_Name, String str_Menge) throws CreateException
  {
    ZutatBean.logger.info("ejbCreateByNameMenge: " + str_Name + ", " + str_Menge);
    this.setZutatName(str_Name);
    this.setMenge(str_Menge);
    this.setId( this.ejbHomeGetNextId() );

    return this.getId();
  }

  /**Erzeugen eines Zutat-Objekts, Name und Menge sind noch nicht gegeben. Der Primary Key wird in der Methode
   * erzeugt.
   * @return Die ID
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Integer ejbCreate () throws CreateException
  {
    ZutatBean.logger.info("ejbCreate");
    this.setId( this.ejbHomeGetNextId() );

    return this.getId();
  }

  /**Nach dem Erzeugen eines Zutat-Objekts, wobei Name und Menge angegeben werden: nichts besonderes zu tun.
   * @param str_Name Der Name der Zutat.
   * @param str_Menge Menge der Zutat
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByNameMenge (String str_Name, String str_Menge) throws CreateException
  {
    ZutatBean.logger.info("ejbPostCreateByNameMenge: " + str_Name + ", " + str_Menge);
  }

  /**Nach dem Erzeugen eines Zutat-Objekts, Name und Menge sind noch nicht gegeben.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate () throws CreateException
  {
    ZutatBean.logger.info("ejbPostCreate");
  }
}