package com.knauf.ejb.kuchenzutatautopk;

import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.EntityContext;
import javax.ejb.EntityBean;

/**
 * Title:
 * Description:  Diese Bean bildet eine Zutat fr den Kuchen ab.
 *               Werte sind:
 *               a) Autogenerierter Primary Key.
 *               b) Name der Zutat
 *               c) Menge
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public abstract class ZutatAutoPKBean implements EntityBean
{
  private EntityContext entityContext = null;

  private static final Logger logger = Logger.getLogger ( ZutatAutoPKBean.class.getName() );

  public ZutatAutoPKBean()
  {
  }

  public void ejbActivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("ejbActivate");
  }
  public void ejbLoad() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("ejbLoad");
  }
  public void ejbPassivate() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("ejbPassivate");
  }
  public void ejbRemove() throws javax.ejb.RemoveException, javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("ejbRemove");
  }
  public void ejbStore() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("ejbStore");
  }
  public void unsetEntityContext() throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("unsetEntityContext");
    this.entityContext = null;
  }
  public void setEntityContext(EntityContext parm1) throws javax.ejb.EJBException, java.rmi.RemoteException
  {
    ZutatAutoPKBean.logger.info("setEntityContext");
    this.entityContext = parm1;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////
  public abstract String getZutatName();

  public abstract void setZutatName (String str_Name);

  public abstract String getMenge();

  public abstract void setMenge (String str_Menge);

  /**Abrufen des Kuchens, zu dem die Zutat gehrt.
   * @return Der Kuchen der Zutat.
   */
  public abstract LocalKuchenAutoPK getKuchen();

  /**Setzen des Kuchens, zu dem die Zutat gehrt.
   * @param kuchen Der Kuchen der Zutat.
   */
  public abstract void setKuchen(LocalKuchenAutoPK kuchen);

  //////////////////////////////////////////////////////////////////////////////////
  //                          Weitere Methoden                                    //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Zutat-Objekts, wobei Name und Menge angegeben wird. Der Key wird vom Container
   * erzeugt.
   * @param str_Name Der Name der Zutat
   * @param str_Menge Die Menge der Zutat
   * @return Immer NULL.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreateByNameMenge (String str_Name, String str_Menge) throws CreateException
  {
    ZutatAutoPKBean.logger.info("ejbCreateByNameMenge: " + str_Name + ", " + str_Menge);
    this.setZutatName(str_Name);
    this.setMenge(str_Menge);

    return null;
  }

  /**Erzeugen eines Zutat-Objekts, Name und Menge sind noch nicht gegeben. Der Primary Key wird vom Container
   * erzeugt.
   * @return Immer NULL
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreate () throws CreateException
  {
    ZutatAutoPKBean.logger.info("ejbCreate");

    return null;
  }

  /**Nach dem Erzeugen eines Zutat-Objekts, wobei Name und Menge angegeben werden: nichts besonderes zu tun.
   * @param str_Name Der Name der Zutat.
   * @param str_Menge Menge der Zutat
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByNameMenge (String str_Name, String str_Menge) throws CreateException
  {
    ZutatAutoPKBean.logger.info("ejbPostCreateByNameMenge: " + str_Name + ", " + str_Menge);
  }

  /**Nach dem Erzeugen eines Zutat-Objekts, Name und Menge sind noch nicht gegeben.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate () throws CreateException
  {
    ZutatAutoPKBean.logger.info("ejbPostCreate");
  }
}