package com.knauf.ejb.messagebean;

import java.util.logging.Level;
import java.util.logging.Logger;
import javax.ejb.EJBException;
import javax.ejb.MessageDrivenContext;
import javax.ejb.MessageDrivenBean;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

/**
 * Title:
 * Description:  Beispielanwendung fr eine MessageDriven Bean: Beanklasse selbst.
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public class MessageBean implements MessageDrivenBean, MessageListener
{
  /**Der Context der Bean */
  private MessageDrivenContext messageContext = null;

  /**Der Logger fr die Logausgaben */
  private static final Logger logger = Logger.getLogger ( MessageBean.class.getName() );

  /**MessageBean wird entfernt. Hier muss nichts geschehen.
   *
   */
  public void ejbRemove()
  {
    MessageBean.logger.info ("ejbRemove");
  }

  /**Create-Methode muss angegeben werden (sonst meckert J2EE-Compliance-Verifier).
   * Sie macht nichts.
   *
   */
  public void ejbCreate()
  {
    MessageBean.logger.info ("ejbCreate");
  }

  /**Setzen des Contexts.
   * @param messageContext Der MessageContext
   */
  public void setMessageDrivenContext(MessageDrivenContext messageContext)
  {
    MessageBean.logger.info ("setMessageDrivenContext");
    this.messageContext = messageContext;
  }

  /**Methode aus Interface "MessageListener": Ausfhren der bergebenen Message.
   * Hier erfolgt nur eine Logausgabe.
   * Alle JMS-Fehler werden als EJB-Exception behandelt.
   * @param message Die zu verarbeitende Message.
   */
  public void onMessage(Message message)
  {
    try
    {
      MessageBean.logger.info("onMessage: Message vom Typ " + message.getClass().toString() + " erhalten");
      if (message instanceof TextMessage)
      {
        TextMessage textMessage = (TextMessage) message;
        MessageBean.logger.info("TextMessage enthlt diesen Text: " + textMessage.getText() );
      }
      else
        MessageBean.logger.info("Sonstige Message. toString() = " + message.toString() );
    }
    catch (JMSException jex)
    {
      MessageBean.logger.log( Level.SEVERE, "Fehler beim Verarbeiten der Message: " + jex.getMessage(), jex );
      throw new EJBException ("Fehler beim Verarbeiten der Message: " + jex.getMessage(), jex );
    }
  }
}