/*
 * Created on 14.11.2004
 *
 */
package com.knauf.ejb.nm;

import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.logging.Logger;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

/**
 * @author WKnauf Entity-Bean fr einen einzelnen Buchstaben. Sie hat als
 *         einziges persistentes Feld das Feld "Buchstabe" mit einem Wert von a -
 *         z (nicht case-sensitiv). Sie hat eine Collection von Worten, die
 *         diesen Buchstaben enthalten.
 */
public abstract class BuchstabeBean implements EntityBean
{
  /**Der Entity-Context der Bean, wenn aktiv.*/
  private EntityContext entityContext = null;

  /**Logausgaben. */
  private static final Logger logger = Logger.getLogger ( BuchstabeBean.class.getName() );

  /* Bean wird aktiviert. Nichts tun.
   * 
   * @see javax.ejb.EntityBean#ejbActivate()
   */
  public void ejbActivate() throws EJBException, RemoteException
  {
    BuchstabeBean.logger.info("ejbActivate");
  }

  /* Bean wird geladen. Nichts zu tun.
   * @see javax.ejb.EntityBean#ejbLoad()
   */
  public void ejbLoad() throws EJBException, RemoteException
  {
    BuchstabeBean.logger.info("ejbLoad");
  }

  /* Bean wird passiviert. Nichts zu tun.
   * 
   * @see javax.ejb.EntityBean#ejbPassivate()
   */
  public void ejbPassivate() throws EJBException, RemoteException
  {
    BuchstabeBean.logger.info("ejbPassivate");

  }

  /* Bean wird gelscht. Nichts zu tun.
   * @see javax.ejb.EntityBean#ejbRemove()
   */
  public void ejbRemove() throws RemoveException, EJBException, RemoteException
  {
    BuchstabeBean.logger.info("ejbRemove");
  }

  /* Bean wird gespeichert. Nichts zu tun.
   * 
   * @see javax.ejb.EntityBean#ejbStore()
   */
  public void ejbStore() throws EJBException, RemoteException
  {
    BuchstabeBean.logger.info("ejbStore");
  }

  /* Entity-Context wird zurckgesetzt. Nichts weiter zu tun.
   * 
   * @see javax.ejb.EntityBean#unsetEntityContext()
   */
  public void unsetEntityContext() throws EJBException, RemoteException
  {
    this.entityContext = null;
    BuchstabeBean.logger.info("unsetEntityContext");
  }

  /* Entity-Context wird gesetzt. Nichts zu tun.
   * @param entityContext der neue Entity-context.
   * @see javax.ejb.EntityBean#setEntityContext(javax.ejb.EntityContext)
   */
  public void setEntityContext(EntityContext entityContext) throws EJBException,
      RemoteException
  {
    BuchstabeBean.logger.info("setEntityContext");
    this.entityContext = entityContext;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////

  /**Abrufen des Buchstabens.
   * @return der Buchstabe.
   */
  public abstract String getBuchstabe();

  /**Setzen des Buchstabens.
   * @param str_Buchstabe Der Buchstabe
   */
  public abstract void setBuchstabe (String str_Buchstabe);

  /**Abrufen aller Worte mit diesem Buchstaben.
   * @return Collection von Wort-Objekten.
   */
  public abstract Collection getWorte();

  /**Setzen der kompletten Wort-Liste des Buchstabens.
   * Wird vom Container bernommen.
   * @param coll_Worte Liste der Worte, die diesen Buchstaben enthalten.
   */
  public abstract void setWorte (Collection coll_Worte);
  
  /**Hinzufgen eines Worts zu den Worten dieses Buchstabens (die einzige Business-Methode).
   * @param wort Das zuzufgende Wort.
   * Wenn es bereits vorkommt, geschieht nichts.
   */
  public void addWort (LocalWort wort)
  {
    try
    {
      BuchstabeBean.logger.info("addWort: '" + wort.getWort() + "'" );
      Collection collWorte = this.getWorte();
      //Prfen, ob Wort bereits vorkommt.
      boolean bolVorhanden = false;
      Iterator iteratorWort = collWorte.iterator();
      while (iteratorWort.hasNext() == true && bolVorhanden == false)
      {
        //Ist das aktuelle Wort das bergebene Wort ?
        LocalWort wortAktuell = (LocalWort) iteratorWort.next();
        if (wortAktuell.getWort().equals(wort.getWort() ) == true)
          bolVorhanden = true;
      }
    
      //Zufgen, wenn es den Buchstaben noch nicht in der Liste gibt.
      if (bolVorhanden == false)
      {
        BuchstabeBean.logger.info("addWort: Wort '" + wort.getWort() + "' muss zugefgt werden." );
        collWorte.add( wort);
      }
      else
        BuchstabeBean.logger.info("addWort: Wort '" + wort.getWort() + "' ist bereits dem Buchstaben zugeordnet." );
    }
    catch (RemoteException rex)
    {
      throw new EJBException ("RemoteException beim Zufgen eines Buchstabens: " + rex.getMessage(), rex);
    }
  }

  /**Abrufen der Wortliste.
   * NUR hierber darf ein Client an die Worte kommen. "getWorte" ist nur fr den Container ?
   * @return Eine Liste aller Worte.
   */
  public ArrayList getWortListe()
  {
    ArrayList list = new ArrayList();
    Iterator c = this.getWorte().iterator();
    while (c.hasNext())
    {
      list.add((LocalWort)c.next());
    }
    return list;
  }
  
  //////////////////////////////////////////////////////////////////////////////////
  //                          Aus dem Home-Interface                              //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Buchstabe-Objekts, wobei der Buchstabe angegeben wird. Der Key wird automatisch erzeugt.
   * @param str_Buchstabe Der Buchstabe. Sollte Unique sein.
   * @return Immer NULL, da der Primary Key vom Container verwaltet wird.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreateByBuchstabe(String str_Buchstabe) throws CreateException
  {
    BuchstabeBean.logger.info("ejbCreateByBuchstabe: " + str_Buchstabe);
    this.setBuchstabe(str_Buchstabe);

    return null;
  }

  /**Nach dem Erzeugen eines Buchstaben-Objekts, wobei der Name angegeben wird: nichts besonderes zu tun.
   * @param str_Buchstabe Der Buchstabe (a-z)
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByBuchstabe (String str_Buchstabe) throws CreateException
  {
    BuchstabeBean.logger.info("ejbPostCreateByName: " + str_Buchstabe);
  }
  
  /**Erzeugen eines Buchstabe-Objekts ohne weitere Parameter. Der Key wird automatisch erzeugt.
   * Scheinbar nur fr J2EE-Verifiert ntig.
   * @return Immer NULL, da der Primary Key vom Container verwaltet wird.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreate() throws CreateException
  {
    BuchstabeBean.logger.info("ejbCreate");

    return null;
  }

  /**Nach dem Erzeugen eines Buchstabe-Objekts, ohne weitere Parameter: nichts besonderes zu tun.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate() throws CreateException
  {
    BuchstabeBean.logger.info("ejbPostCreate");
  }
}