/*
 * Created on 14.11.2004
 *
 */
package com.knauf.ejb.nm;

import java.rmi.RemoteException;
import java.util.Collection;

import javax.ejb.CreateException;
import javax.ejb.EJBLocalHome;
import javax.ejb.FinderException;

/**
 * @author WKnauf
 *
 * Local Interface der Bean "Wort" mit den Finder-und Create-Methoden.
 */
public interface LocalWortHome extends EJBLocalHome
{
  /**Erzeugen eines Wort-Objekts, wobei das Wort angegeben wird. Der Key wird automatisch erzeugt.
   * @param str_Wort Das Wort. Sollte Unique sein.
   * @return Das erzeugte Wort.
   * @exception CreateException Fehler beim Erzeugen.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalWort createByWort(String str_Wort) throws CreateException, RemoteException;

  /**Erzeugen eines Wort-Objekts ohne weitere Details. Der Key wird automatisch erzeugt.
   * Scheinbar nur ntig, weil der J2EE-Verifier sonst meckert.
   * @return Das erzeugte Wort.
   * @exception CreateException Fehler beim Erzeugen.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalWort create() throws CreateException, RemoteException;

  
  /**Laden eines Wort-Objekts anhand des Primary Keys. Der Key wird vom Container verwaltet.
   * @param obj_PrimaryKey Der Key des Worts.
   * @return Das anhand des Keys gefundene Wort
   * @exception FinderException Fehler beim Finden.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalWort findByPrimaryKey(Object obj_PrimaryKey) throws FinderException, RemoteException;

  /**Laden eines Wort-Objekts anhand des Worts (sollte unique sein).
   * @param str_Wort Das Wort. Entweder es gibt das Wort bereits, oder es wird eine Finder-Exception
   * zurckgeliefert.
   * @return Das anhand des Keys gefundene Wort.
   * @exception FinderException Fehler beim Finden.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public LocalWort findByWort(String str_Wort) throws FinderException, RemoteException;


  /**Laden aller Wort-Objekte.
   * @return Eine Collection aller Worte
   * @exception FinderException Fehler beim Finden.
   * @exception RemoteException Bei Netzwerkfehlern.
   */
  public Collection findAll() throws FinderException, RemoteException;
}
