/*
 * Created on 14.11.2004
 *
 */
package com.knauf.ejb.nm;

import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.logging.Logger;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

/**
 * @author WKnauf
 *
 * Bean-Klasse fr ein Wort. 
 * Jedes Wort besteht aus n Buchstaben, jeder Buchstabe ist mit einer Liste von
 * Worten verknpft, aus denen er besteht.
 */
public abstract class WortBean implements EntityBean
{
  /**Der Entity-Context der Bean, wenn aktiv.*/
  private EntityContext entityContext = null;

  /**Logausgaben. */
  private static final Logger logger = Logger.getLogger ( WortBean.class.getName() );

  /* Bean wird aktiviert. Nichts tun.
   * 
   * @see javax.ejb.EntityBean#ejbActivate()
   */
  public void ejbActivate() throws EJBException, RemoteException
  {
    WortBean.logger.info("ejbActivate");
  }

  /* Bean wird geladen. Nichts zu tun.
   * @see javax.ejb.EntityBean#ejbLoad()
   */
  public void ejbLoad() throws EJBException, RemoteException
  {
    WortBean.logger.info("ejbLoad");
  }

  /* Bean wird passiviert. Nichts zu tun.
   * 
   * @see javax.ejb.EntityBean#ejbPassivate()
   */
  public void ejbPassivate() throws EJBException, RemoteException
  {
    WortBean.logger.info("ejbPassivate");

  }

  /* Bean wird gelscht. Nichts zu tun.
   * @see javax.ejb.EntityBean#ejbRemove()
   */
  public void ejbRemove() throws RemoveException, EJBException, RemoteException
  {
    WortBean.logger.info("ejbRemove");
  }

  /* Bean wird gespeichert. Nichts zu tun.
   * 
   * @see javax.ejb.EntityBean#ejbStore()
   */
  public void ejbStore() throws EJBException, RemoteException
  {
    WortBean.logger.info("ejbStore");
  }

  /* Entity-Context wird zurckgesetzt. Nichts weiter zu tun.
   * 
   * @see javax.ejb.EntityBean#unsetEntityContext()
   */
  public void unsetEntityContext() throws EJBException, RemoteException
  {
    this.entityContext = null;
    WortBean.logger.info("unsetEntityContext");
  }

  /* Entity-Context wird gesetzt. Nichts zu tun.
   * @param entityContext der neue Entity-context.
   * @see javax.ejb.EntityBean#setEntityContext(javax.ejb.EntityContext)
   */
  public void setEntityContext(EntityContext entityContext) throws EJBException,
      RemoteException
  {
    WortBean.logger.info("setEntityContext");
    this.entityContext = entityContext;
  }

  //////////////////////////////////////////////////////////////////////////////////
  //                   Zugriffsmethoden fr die Felder                            //
  //////////////////////////////////////////////////////////////////////////////////

  /**Abrufen des Worts (sollte Unique sein)
   * @return Das Wort
   */
  public abstract String getWort();

  /**Setzen des Worts (sollte Unique sein)
   * @param str_Wort Das Wort
   */
  public abstract void setWort (String str_Wort);

  /**Abrufen aller Buchstaben, aus denen dieses Wort besteht.
   * @return Collection von Buchstabe-Objekten.
   */
  public abstract Collection getBuchstaben();

  /**Setzen der kompletten Buchstaben-Liste des Worts.
   * Wird vom Container bernommen.
   * @param coll_Buchstaben Liste der Buchstaben, aus denen dieses Wort besteht. 
   * Sollte keine Duplikate enthalten.
   */
  public abstract void setBuchstaben (Collection coll_Buchstaben);
  
  /**Hinzufgen eines Buchstaben zu den Buchstaben dieses Worts (die einzige Business-Methode).
   * @param buchstabe Der zuzufgende Buchstabe.
   * Wenn er bereits vorkommt, geschieht nichts (Wort enthlt einen Buchstabe doppelt).
   */
  public void addBuchstabe (LocalBuchstabe buchstabe)
  {
    try
    {
      WortBean.logger.info("addBuchstabe: '" + buchstabe.getBuchstabe() + "'" );
      Collection collBuchstaben = this.getBuchstaben();
      //Prfen, ob Buchstabe bereits vorkommt.
      boolean bolVorhanden = false;
      Iterator iteratorBuchstabe = collBuchstaben.iterator();
      while (iteratorBuchstabe.hasNext() == true && bolVorhanden == false)
      {
        //Ist der aktuelle Buchstabe der bergebene Buchstabe ?
        LocalBuchstabe buchstabeAktuell = (LocalBuchstabe) iteratorBuchstabe.next();
        if (buchstabeAktuell.getBuchstabe().equals(buchstabe.getBuchstabe() ) == true)
          bolVorhanden = true;
      }
    
      //Zufgen, wenn es den Buchstaben noch nicht in der Liste gibt.
      if (bolVorhanden == false)
      {
        WortBean.logger.info("addBuchstabe: Buchstabe '" + buchstabe.getBuchstabe() + "' muss zugefgt werden." );
        collBuchstaben.add( buchstabe);
      }
      else
        WortBean.logger.info("addBuchstabe: Buchstabe '" + buchstabe.getBuchstabe() + "' ist bereits dem Wort zugeordnet." );
    }
    catch (RemoteException rex)
    {
      throw new EJBException ("RemoteException beim Zufgen eines Buchstabens: " + rex.getMessage(), rex);
    }
  }
  
  /**Entfernen eines Buchstabens aus den Buchstaben dieses Worts.
   * @param buchstabe Der zu entfernende Buchstabe. Falls er nicht vorhanden ist,
   * wird eine EJB-Exception ausgelst.
   */
  public void removeBuchstabe (LocalBuchstabe buchstabe)
  {
    try
    {
      WortBean.logger.info("removeBuchstabe: '" + buchstabe.getBuchstabe() + "'" );
      Collection collBuchstaben = this.getBuchstaben();
      Iterator iteratorBuchstabe = collBuchstaben.iterator();
      //Der so gefundene Buchstabe (wird gesetzt, falls er gefunden wird).
      LocalBuchstabe buchstabeVorhanden = null;
      while (iteratorBuchstabe.hasNext() == true && buchstabeVorhanden == null)
      {
        //Ist der aktuelle Buchstabe der bergebene Buchstabe ?
        LocalBuchstabe buchstabeAktuell = (LocalBuchstabe) iteratorBuchstabe.next();
        if (buchstabeAktuell.getBuchstabe().equals(buchstabe.getBuchstabe() ) == true)
          buchstabeVorhanden = buchstabeAktuell;
      }
    
      //Wenn Buchstabe nicht vorhanden ist, dann EJB-Exception auslsen.
      if (buchstabeVorhanden == null)
      {
        throw new EJBException ("Buchstabe '" + buchstabe.getBuchstabe() + "' ist in Buchstaben des Worts nicht enthalten.");
      }
      
      //Entfernen:
      collBuchstaben.remove(buchstabeVorhanden);
      //Mss wir hier noch Setzen ?!?!?!?
    }
    catch (RemoteException rex)
    {
      throw new EJBException ("RemoteException beim Zufgen eines Buchstabens: " + rex.getMessage(), rex);
    }
  }

  /**Abrufen der Buchstabenliste.
   * NUR hierber darf ein Client an die Buchstaben kommen. "getBuchstaben" ist nur fr den Container ?
   * @return Eine Liste aller Buchstaben.
   */
  public ArrayList getBuchstabenListe()
  {
    ArrayList list = new ArrayList();
    Iterator c = this.getBuchstaben().iterator();
    while (c.hasNext())
    {
      list.add((LocalBuchstabe)c.next());
    }
    return list;
  }
  
  //////////////////////////////////////////////////////////////////////////////////
  //                          Aus dem Home-Interface                              //
  //////////////////////////////////////////////////////////////////////////////////

  /**Erzeugen eines Wort-Objekts, wobei das Wort angegeben wird. Der Key wird automatisch erzeugt.
   * @param str_Wort Das Wort. Sollte Unique sein.
   * @return Immer NULL, da der Primary Key vom Container verwaltet wird.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreateByWort(String str_Wort) throws CreateException
  {
    WortBean.logger.info("ejbCreateByWort: " + str_Wort);
    this.setWort(str_Wort);

    return null;
  }

  /**Nach dem Erzeugen eines Wort-Objekts, wobei das Wort selbst angegeben wird: nichts besonderes zu tun.
   * @param str_Wort Das Wort.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreateByWort (String str_Wort) throws CreateException
  {
    WortBean.logger.info("ejbPostCreateByWort: " + str_Wort);
  }
  
  /**Erzeugen eines Wort-Objekts ohne weitere Parameter. Der Key wird automatisch erzeugt.
   * Scheinbar nur fr J2EE-Verifiert ntig.
   * @return Immer NULL, da der Primary Key vom Container verwaltet wird.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public Object ejbCreate() throws CreateException
  {
    WortBean.logger.info("ejbCreate");

    return null;
  }

  /**Nach dem Erzeugen eines Wort-Objekts, ohne weitere Parameter: nichts besonderes zu tun.
   * @exception CreateException Fehler beim Erzeugen.
   */
  public void ejbPostCreate() throws CreateException
  {
    WortBean.logger.info("ejbPostCreate");
  }
}
