package com.knauf.ejb.security;

import java.util.logging.Logger;
import javax.ejb.CreateException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

/**
 * Title:
 * Description:  Stateless Session Bean mit zwei primitiven Methoden fr den Security Test.
 * Fr die Methoden bestehen unterschiedliche Berechtigungen.
 * Copyright:    Copyright (c) 2004
 * Company:
 * @author
 * @version 1.0
 */

public class SecurityBean implements SessionBean
{
  /**Session-Context */
  private SessionContext sessionContext = null;

  /**Der statische Logger */
  private static final Logger logger = Logger.getLogger ( SecurityBean.class.getName() );

  /**Konstruktor.
   *
   */
  public SecurityBean()
  {
  }

  /**Bean wird aktiviert: es passiert nichts.
   *
   */
  public void ejbActivate()
  {
    SecurityBean.logger.info ("ejbActivate: " + this.getUserString() );
  }

  /**Bean wird passiviert: es passiert nichts.
   *
   */
  public void ejbPassivate()
  {
    SecurityBean.logger.info ("ejbPassivate: " + this.getUserString());
  }

  /**Bean wird entfernt. Nichts zu tun.
   *
   */
  public void ejbRemove()
  {
    SecurityBean.logger.info ("ejbRemove: " + this.getUserString());
  }

  /**Setzen des Session-Context.
   * @param sessionContext Der neue SessionContext
   */
  public void setSessionContext(SessionContext sessionContext)
  {
    SecurityBean.logger.info ("setSessionContext: " + this.getUserString());

    this.sessionContext = sessionContext;
  }

  /////////////////////////////////////////////////////////////////
  //         Methoden aus Home-Interface                         //
  /////////////////////////////////////////////////////////////////

  /**Erzeugen einer Instanz. Hier muss nichts geschehen.
   * @exception CreateException Falls Fehler beim Erzeugen auftreten.
   */
  public void ejbCreate() throws javax.ejb.CreateException
  {
    //Hier keine Ausgabe der User-Daten...


    SecurityBean.logger.info ("create SecurityBean");
  }

  /////////////////////////////////////////////////////////////////
  //          Methoden aus Remote-Interface                      //
  /////////////////////////////////////////////////////////////////

  /**Diese Methode ist per Deployment auf Rolle 1 beschrnkt.
   * Sonst hat sie keine Bedeutung.
   * @exception RemoteException Netzwerkfehler.
   */
  public void performRestrictedToRole1 ()
  {
    SecurityBean.logger.info("performRestrictedToRole1: " + this.getUserString() );
  }

  /**Diese Methode ist per Deployment auf Rolle 2 beschrnkt.
   * Sonst hat sie keine Bedeutung.
   * @exception RemoteException Netzwerkfehler.
   */
  public void performRestrictedToRole2 ()
  {
    SecurityBean.logger.info("performRestrictedToRole2: " + this.getUserString() );
  }

  /**Diese Methode ist per Deployment auf keine Rolle beschrnkt, d.h. fr alle verfgbar.
   * Sonst hat sie keine Bedeutung.
   * @exception RemoteException Netzwerkfehler.
   */
  public void performUnrestricted()
  {
    SecurityBean.logger.info("performUnrestricted: " + this.getUserString() );
  }

  /////////////////////////////////////////////////////////////////////
  //                 Hilfsmethoden                                   //
  /////////////////////////////////////////////////////////////////////

  /**Auswerten, ob der User in einer bestimmten Rolle ist.
   * @return Einen String der Form "Username, Role1 ? true, Role2 ? false"
   */
  private String getUserString ()
  {
    if (this.sessionContext == null)
      return "---kein SessionContext---";

    String strUser = this.sessionContext.getCallerPrincipal().getName();
    //Beim Abfragen der Rollen: hier werden Alias-Namen verwendet, die als Role-Refs im Deployment-Descriptor
    //stehen.
    strUser += ", Role1 ? " + this.sessionContext.isCallerInRole("Role1Ref");
    strUser += ", Role2 ? " + this.sessionContext.isCallerInRole("Role2Ref");

    return strUser;
  }
}